@@ -15,8 +15,8 @@
 //
 // You should have received a copy of the GNU General Public License
 // along with GCC; see the file COPYING.  If not, write to
-// the Free Software Foundation, 59 Temple Place - Suite 330,
-// Boston, MA 02111-1307, USA.
+// the Free Software Foundation, 51 Franklin Street, Fifth Floor,
+// Boston, MA 02110-1301, USA.
 
 // As a special exception, you may use this file as part of a free software
 // library without restriction.  Specifically, if other files instantiate
@@ -27,7 +27,6 @@
 // invalidate any other reasons why the executable file might be covered by
 // the GNU General Public License.
 
-
 #include <cstdlib>
 #include "unwind-cxx.h"
 
@@ -38,9 +37,8 @@ __cxxabiv1::__cxa_get_exception_ptr(void *exc_obj_in) throw()
 {
   _Unwind_Exception *exceptionObject
     = reinterpret_cast <_Unwind_Exception *>(exc_obj_in);
-  __cxa_exception *header = __get_exception_header_from_ue (exceptionObject);
 
-  return header->adjustedPtr;
+  return __gxx_caught_object(exceptionObject);
 }
 
 extern "C" void *
@@ -51,12 +49,13 @@ __cxxabiv1::__cxa_begin_catch (void *exc_obj_in) throw()
   __cxa_eh_globals *globals = __cxa_get_globals ();
   __cxa_exception *prev = globals->caughtExceptions;
   __cxa_exception *header = __get_exception_header_from_ue (exceptionObject);
+  void* objectp;
 
   // Foreign exceptions can't be stacked here.  If the exception stack is
   // empty, then fine.  Otherwise we really have no choice but to terminate.
   // Note that this use of "header" is a lie.  It's fine so long as we only
   // examine header->unwindHeader though.
-  if (header->unwindHeader.exception_class != __gxx_exception_class)
+  if (!__is_gxx_exception_class(header->unwindHeader.exception_class))
     {
       if (prev != 0)
 	std::terminate ();
@@ -85,7 +84,11 @@ __cxxabiv1::__cxa_begin_catch (void *exc_obj_in) throw()
       globals->caughtExceptions = header;
     }
 
-  return header->adjustedPtr;
+  objectp = __gxx_caught_object(exceptionObject);
+#ifdef __ARM_EABI_UNWINDER__
+  _Unwind_Complete(exceptionObject);
+#endif
+  return objectp;
 }
 
 
@@ -102,7 +105,7 @@ __cxxabiv1::__cxa_end_catch ()
 
   // A foreign exception couldn't have been stacked (see above),
   // so by definition processing must be complete.
-  if (header->unwindHeader.exception_class != __gxx_exception_class)
+  if (!__is_gxx_exception_class(header->unwindHeader.exception_class))
     {
       globals->caughtExceptions = 0;
       _Unwind_DeleteException (&header->unwindHeader);
